using_github_codespaces checks whether code is being run in a
GitHub Codespaces environment.
using_github_actions() reports whether GitHub Actions is being
used
using_github_codespaces checks whether code is being run in a
GitHub Codespaces environment.
using_github_actions() reports whether GitHub Actions is being
used